{###############################################################################}
{##}
{#   Copyright (C) <2016>  <Florian Alu - Prolibre - http://prolibre.com>#}
{##}
{#    This program is free software: you can redistribute it and/or modify#}
{#    it under the terms of the GNU Affero General Public License as published#}
{#    by the Free Software Foundation, either version 3 of the License.#}
{#    #}
{##}
{#    This program is distributed in the hope that it will be useful,#}
{#    but WITHOUT ANY WARRANTY; without even the implied warranty of#}
{#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the#}
{#    GNU Affero General Public License for more details.#}
{##}
{#    You should have received a copy of the GNU Affero General Public License#}
{#    along with this program.  If not, see <http://www.gnu.org/licenses/>.#}
{##}
{###############################################################################}

{% if form_show_errors and field.errors %}
    {% for error in field.errors %}
        <p id="error_{{ forloop.counter }}_{{ field.auto_id }}" class="help-block"><strong>{{ error }}</strong></p>
    {% endfor %}
{% endif %}
