{% extends "admin/base_site.html" %}
{% load static %}
{% load i18n %}
{% load crispy_forms_tags %}

{% block content %}
  {% include "includes/messages.html" %}
  <div class="card">
    <div class="card-block">
      <h4 class="card-title">{% blocktrans %}Add official holidays{% endblocktrans %}</h4>
      <p class="card-text">
        {% blocktrans %}This form allows you to add the holidays of the current year.{% endblocktrans %}
      </p>
      {% crispy form form.helper %}
    </div>
  </div>

  <div class="card">

  </div>
{% endblock %}
